# YoLink Python library for HA Integration

## Changelog

### 0.2.3

* api improve.

### 0.2.1

* Add retry when connect to device failure.
* Add YoLink FlexFob support.
* Change api structure.

### 0.1.0

* bug fix for mqtt reconnect fail by authentication information expired.

### 0.0.9 (2022.7.12)

* add parent device

### 0.0.8 (2022.6.8)

* ignore invalid data report

### 0.0.7 (2022.6.6)

* Fix Mqtt Empty data report, Failure by validation

### 0.0.6 (2022.6.2)

* Fix https support

### 0.0.5 (2022.5.9)

* Change YoLink library dependency

### 0.0.4 (2022.5.2)

* YoLink first version python client
